package cc.fascinated.controller;

import cc.fascinated.exception.impl.BadRequestException;
import cc.fascinated.platform.Platform;
import cc.fascinated.services.TrackedScoreService;
import lombok.NonNull;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author Fascinated (fascinated7)
 */
@RestController
@RequestMapping(value = "/scores")
public class ScoresController {
    /**
     * The tracked score service to use.
     */
    @NonNull
    private final TrackedScoreService trackedScoreService;

    @Autowired
    public ScoresController(@NonNull TrackedScoreService trackedScoreService) {
        this.trackedScoreService = trackedScoreService;
    }

    /**
     * A GET mapping to retrieve the top
     * scores for a platform
     *
     * @param platform the platform to get the scores from
     * @return the scores
     * @throws BadRequestException if there were no scores found
     */
    @ResponseBody
    @GetMapping(value = "/top/{platform}")
    public ResponseEntity<List<?>> getTopScores(@PathVariable String platform) {
        return ResponseEntity.ok(trackedScoreService.getTopScores(Platform.Platforms.getPlatform(platform), 100));
    }

    /**
     * A GET mapping to retrieve the total
     * amount of scores for a platform
     *
     * @param platform the platform to get the scores from
     * @return the amount of scores
     * @throws BadRequestException if there were no scores found
     */
    @ResponseBody
    @GetMapping(value = "/count/{platform}")
    public ResponseEntity<?> getScoresCount(@PathVariable String platform) {
        return ResponseEntity.ok(trackedScoreService.getTotalScores(Platform.Platforms.getPlatform(platform)));
    }

    /**
     * A GET mapping to retrieve the total
     * amount of scores over pp thresholds
     *
     * @param platform the platform to get the scores from
     * @return the amount of scores
     * @throws BadRequestException if there were no scores found
     */
    @ResponseBody
    @GetMapping(value = "/ppthresholds/{platform}")
    public ResponseEntity<?> getScoresOver(@PathVariable String platform) {
        return ResponseEntity.ok(trackedScoreService.getScoresOver(Platform.Platforms.getPlatform(platform)));
    }
}
