package cc.fascinated.services;

import io.questdb.client.Sender;
import lombok.Getter;
import lombok.NonNull;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

/**
 * @author Fascinated (fascinated7)
 */
@Service
@Getter
@Log4j2(topic = "QuestDB Service")
public class QuestDBService {
    /*
     * The host of the QuestDB instance.
     */
    private final String host;

    /*
     * The username of the QuestDB instance.
     */
    private final String username;

    /*
     * The password of the QuestDB instance.
     */
    private final String password;

    @Autowired
    public QuestDBService(@Value("${questdb.host}") @NonNull String host,
                          @Value("${questdb.username}") @NonNull String username,
                          @Value("${questdb.password}") @NonNull String password
    ) {
        this.host = host;
        this.username = username;
        this.password = password;
    }

    /**
     * Gets a new sender instance for QuestDB.
     *
     * @return the sender
     */
    public Sender getSender() {
        return Sender.builder(Sender.Transport.HTTP)
                .address(host) // set host
                .httpUsernamePassword(username, password) // set username and password
                .retryTimeoutMillis(3000) // 3 seconds
                .build();
    }
}
